@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/glite/org.glite.lb.client/src/prod_proto.c,v 1.46 2012/12/13 13:31:47 valtri Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -678,6 +678,12 @@ int edg_wll_log_proxy_read(edg_wll_Context ctx, edg_wll_PlainConnection *conn)
 				snprintf(et, sizeof(et), "edg_wll_log_proxy_read(): error details from L&B Proxy server: %s", answer);
 				edg_wll_SetError(ctx, code, et);
 				break;
+			case LB_PERM:
+				edg_wll_SetError(ctx, EPERM, "edg_wll_log_proxy_read(): operation not permitted");
+				break;
+//			case LB_AUTH: // Defined but never used
+//			case LB_SYS: // Defined but never used
+//			case LB_TIME: // Defined but never used
 			default:
 				edg_wll_SetError(ctx, EDG_WLL_IL_PROTO, "edg_wll_log_proxy_read(): received unknown protocol response"); 
 				break;
@@ -849,9 +855,15 @@ int edg_wll_log_direct_read(edg_wll_Context ctx, edg_wll_GssConnection *con)
 				edg_wll_SetError(ctx, EDG_WLL_IL_PROTO, "edg_wll_log_direct_read(): received protocol error response"); 
 				break;
 			case LB_DBERR:
-				snprintf(et, sizeof(et), "edg_wll_log_direct_read: error details from L&B server: %s", answer);
+				snprintf(et, sizeof(et), "edg_wll_log_direct_read(): error details from L&B server: %s", answer);
 				edg_wll_SetError(ctx, code, et);
 				break;
+			case LB_PERM:
+				edg_wll_SetError(ctx, EPERM, "edg_wll_log_direct_read(): operation not permitted");
+				break;
+//			case LB_AUTH: // Defined but never used
+//			case LB_SYS: // Defined but never used
+//			case LB_TIME: // Defined but never used
 			default:
 				edg_wll_SetError(ctx, EDG_WLL_IL_PROTO, "edg_wll_log_direct_read(): received unknown protocol response"); 
 				break;
